Date: 06 23, 2001 10:41:34 AM

# Setting Concept Properties

To set concept properties for rule concepts:

1. In the Gram Tab, select the rule concept.

2. Right click and select Properties from the pulldown menu. The Gram Concept Properties dialog is opened.

3. Check or uncheck the boxes for the appropriate attribute. (See Setting Rule Generation Properties for a description of the attributes.)

4. Click Done to finish setting the properties.